# Todo

- remover o modo monocromático
- corrigir o arquivo ansi gerado que está redundante

- add modelo pra converter entre markdown table para testes e tio
- tempo label do lado to fixar label ao lado dos cases
- +- label ao lado do tab para habilitar e desabilitar
- +- no mesmo simbolo se possível

- corrigir o DiffBuilder para adicionar ou remover as bordas
- se colocar as bordas, adicionar automaticamente a borda da direita.
- ao invés de fazer o scrollbar do lado direito, fazer elem embaixo

- pasta user para adicionar problemas do usuário
- paleta embaixo abrindo floating com textos pendurados em functors
- opção de mostrar quantos testes passaram no principal
- opção de rodar os testes no computador do aluno
- for each folder tko test folder --compact

## Feedback

- Como sua autonomia e compreensão das técnicas apresentadas na atividade.
- Autonomia: Uso de ajuda externa. (grupo, monitor, colega, copilot, chatgpt, internet, tutorial)
- Compreensão: Nível de compreensão do conteúdo em 4 níveis. (superficial, básico, funcional, profundo)

## Tabela de autonomia vs compreensão

| Autonomia \ Compreensão          | 😕 Superficial:Confuso | 😬 Básico:Inseguro | 😌 Funcional:Capaz | 😎 Profundo:Confiante |
| -------------------------------- | ----------------------- | ------------------- | ------------------- | ---------------------- |
| ✋ Sozinho:sem ajuda             |                         |                     | 7   90%             | 9  110%                |
| 💡 Pouca ajuda:dicas            |                         |                     | 6   75%             | 8  100%                |
| 🤝 Muita ajuda:idéias e códigos |                         | 3 35%               | 5   60%             |                        |
| 🧭 Guiado:tutorial ou aula      | 1  15%                  | 2 25%               | 4   45%             |                        |

## Features

- 3 modos de fazer a tarefa
  - sozinho
  - ajuda (grupo, monitor, colega, IA, internet)
  - guiado (aula, vídeo, tutorial)
- 3 níveis de compreensão do conteúdo
  - superficial
  - intermediário
  - profundo
- 3 níveis de dificuldade
  - fácil
  - médio
  - difícil
